Utility function based on `assignList()` from the package `tis` by Jeff Hallman (https://github.com/cran/tis/blob/master/R/assignList.R). Assigns the values in a list to variables in an environment. The variable names are taken from the names of the list, so all of the elements of the list must have non-blank names.

assign_list(a_list, pos = -1, envir = as.environment(pos), inherits = FALSE)

Arguments

a_list

Named list whose values will be assigned into the target environment.

pos

Position of the target environment on the search path.

envir

Environment in which to assign the objects.

inherits

Passed through to [base::assign()].

Value

Invisibly returns `NULL`.