Calculates plume optical classes from eReefs/EMS reflectance outputs using the Devlin et al. (2012) class definitions as adapted for this package.

plume_class(rsr)

Arguments

rsr

List of 2D reflectance arrays in wavelength order: `R_412`, `R_443`, `R_488`, `R_531`, `R_547`, `R_667`, `R_678`.

Value

An integer matrix of the same horizontal shape as the reflectance inputs, with plume class values between 1 and 7.