sv2raster.RdConvert a SpatVector to a raster. (Wrapper for terra::rasterize() with some reasonable defaults for the ereefs package)
sv2raster(
sv,
xmn = 142.45,
ymn = -27.5,
resolution = 0.01,
xmx = NA,
ymx = NA,
r = NULL
)SpatVector object, e.g. as output by poly2sv()
Minimum x value to use for the grid. Defaults to 142.45
Minimum y value for the grid. Defaults to -27.5
Grid resolution in degrees. Defaults to 0.01
A raster object with the correct grid set up (optional). Default=NULL
Maximum x value for the grid. Defaults to max value from the SpatVector extent
Maximum y value for the grid. Defaults to max value from the SpatVector extent
A raster object, as used in the package 'terra'