assign_list.RdUtility function based on `assignList()` from the package `tis` by Jeff Hallman (https://github.com/cran/tis/blob/master/R/assignList.R). Assigns the values in a list to variables in an environment. The variable names are taken from the names of the list, so all of the elements of the list must have non-blank names.
assign_list(a_list, pos = -1, envir = as.environment(pos), inherits = FALSE)Invisibly returns `NULL`.