find_intersections.RdAn internal utility function to find the grid line intersections of a line segment
find_intersections(
geolocation,
x_grid,
y_grid,
latitude,
longitude,
first_point = FALSE
)Two-row latitude/longitude table defining the line segment to trace.
Grid of cell-corner longitudes.
Grid of cell-corner latitudes.
Cell-centre latitude grid.
Cell-centre longitude grid.
Logical; if `TRUE`, include the starting point of the transect in the returned intersection set.