get_origin_and_times.RdOpens the netcdf file, input_file, and extracts the origin (reference date/time) and time dimension.
Opens the netcdf file and extracts the time origin and time dimension using tidync/ncmeta.
get_origin_and_times(input_file)
get_origin_and_times(input_file)A list containing ereefs_origin (the reference data/time used in the netcdf file) and the time series, ds
A list containing ereefs_origin (the reference date/time used in the netcdf file), the POSIXct time series, and the raw numeric time coordinate.