map_ereefs_movie.RdRepeatedly calls [map_ereefs()] over a date range, saving frame images when requested and optionally assembling them into a GIF or MP4 animation.
map_ereefs_movie(
var_name = "true_colour",
start_date = c(2015, 12, 1),
end_date = c(2016, 3, 31),
layer = "surface",
output_dir = "ToAnimate",
save_frames = TRUE,
animation_format = c("none", "gif", "mp4", "mp3"),
animation_file = NA,
fps = 2,
Land_map = FALSE,
input_file = "catalog",
input_grid = NA,
scale_col = "viridis",
scale_lim = c(NA, NA),
plot_style = c("polygon", "smooth"),
smooth_pixels = 600,
zoom = 6,
box_bounds = c(NA, NA, NA, NA),
suppress_print = TRUE,
stride = "daily",
verbosity = 0,
label_towns = TRUE,
strict_bounds = FALSE,
mark_points = NULL,
gbr_poly = FALSE,
add_arrows = FALSE,
max_u = NA,
scale_arrows = NA,
show_bathy = FALSE,
contour_breaks = c(5, 10, 20)
)Variable to plot. Special values `"true_colour"` and `"plume"` are also supported.
Start of the animation period.
End of the animation period.
Layer selector. Use a positive layer index, a negative depth below mean sea level, or `"surface"`/`"bottom"`.
Directory in which to save frame images and animation outputs.
Logical; save individual frame PNG files.
One of `"none"`, `"gif"`, `"mp4"`, or legacy `"mp3"` (which is treated as `"mp4"` with a warning).
Optional output filename for the assembled animation.
Frames per second for assembled animations.
Logical; add a simple land underlay where available.
NetCDF file path, OPeNDAP URL, or THREDDS catalog URL.
Optional alternative source for grid metadata.
Colour scale specification. Defaults to `"viridis"` for scalar maps.
Numeric colour limits. If left as `NA`, limits are inferred from the extracted data.
Either `"polygon"` or `"smooth"`.
Resolution used for `"smooth"` display maps.
Deprecated legacy argument retained for backward compatibility.
Optional bounds in the form `c(longitude_min, longitude_max, latitude_min, latitude_max)`.
Logical; if `TRUE`, suppresses automatic printing.
Temporal stride used to choose frames.
Verbosity level for progress messages.
Logical; add town labels where available.
Deprecated legacy argument retained for backward compatibility.
Optional locations to mark on the map.
Logical; add GBR polygon overlay when available.
Deprecated legacy argument retained for backward compatibility.
Deprecated legacy argument retained for backward compatibility.
Deprecated legacy argument retained for backward compatibility.
Deprecated legacy argument retained for backward compatibility.
Deprecated legacy argument retained for backward compatibility.
A list containing the final plot, averaged plotting polygons, saved frame filenames, animation filename, and the colour scale limits used across frames.