plot_ereefs_profile.RdRelies on output from get_ereefs_profile().
plot_ereefs_profile(
profileObj,
var_name = "Chl_a_sum",
target_date = c(2016, 1, 1),
p = NA,
colour = "blue"
)A list object as output by get_ereefs_profiles(), containing dates, eta, z_grid, botz and profiles
The name of the variable to plot (must be a colname in profile$profiles). Default 'Chl_a_sum'. If profileObj contains only one variable, var_name is ignored and the content of the profile is shown.
The target date or date-time to plot. Can be a `Date`, `POSIXct`, character string, or a vector such as `c(year, month, day)`.
The handle of an existing figure, if you don't want to create a new figure
the handle of a figure containing the vertical profile plot
if (FALSE) { # \dontrun{
plot_ereefs_profile(get_ereefs_profile('TN'))
} # }