plume_class.RdCalculates plume optical classes from eReefs/EMS reflectance outputs using the Devlin et al. (2012) class definitions as adapted for this package.
plume_class(rsr)An integer matrix of the same horizontal shape as the reflectance inputs, with plume class values between 1 and 7.